DeferredSignerReceiver

Struct DeferredSignerReceiver 

pub struct DeferredSignerReceiver { /* private fields */ }
Receiver half of the deferred signer channel.

Held internally by a deferred signer implementation to receive the concrete signer once it becomes available after HTTP request signing.

Implementations

Source

impl DeferredSignerReceiver

pub fn recv<T: Send + Sync + 'static>( &self, ) -> Result<T, DeferredSignerRecvError>

Receives the value sent by the corresponding DeferredSignerSender.

This consumes the receiver’s channel on first call. Subsequent calls will return an error.