DeferredSignerSender

Struct DeferredSignerSender 

pub struct DeferredSignerSender { /* private fields */ }
Sender for wiring up an event stream message signer after HTTP request signing.

During serialization, a DeferredSignerSender is placed in the config bag. After HTTP signing completes, the auth scheme retrieves it and sends the concrete signer implementation through the channel.

Implementations

Source

impl DeferredSignerSender

pub fn new() -> (DeferredSignerReceiver, Self)

Creates a new sender/receiver pair.

pub fn send<T: Send + Sync + 'static>( &self, value: T, ) -> Result<(), DeferredSignerSendError>

Sends a value through the channel.