pub struct Blob { /* private fields */ }Expand description
Binary Blob Type
Blobs represent protocol-agnostic binary content.
Implementations
Sourceimpl Blob
impl Blob
Creates a new blob, reusing an existing shared allocation when possible.
Sourcepub fn into_bytes(self) -> Bytes
pub fn into_bytes(self) -> Bytes
Consumes the Blob and returns its contents as Bytes.
Sourcepub fn into_inner(self) -> Vec<u8> ⓘ
pub fn into_inner(self) -> Vec<u8> ⓘ
Consumes the Blob and returns a Vec<u8> with its contents.