pub struct DeferredSignerReceiver { /* private fields */ }Expand description
Receiver half of the deferred signer channel.
Held internally by a deferred signer implementation to receive the concrete signer once it becomes available after HTTP request signing.
Implementations
Sourceimpl DeferredSignerReceiver
impl DeferredSignerReceiver
Sourcepub fn recv<T: Send + Sync + 'static>(
&self,
) -> Result<T, DeferredSignerRecvError>
pub fn recv<T: Send + Sync + 'static>( &self, ) -> Result<T, DeferredSignerRecvError>
Receives the value sent by the corresponding DeferredSignerSender.
This consumes the receiver’s channel on first call. Subsequent calls will return an error.