pub struct DeferredSignerSender { /* private fields */ }Expand description
Sender for wiring up an event stream message signer after HTTP request signing.
During serialization, a DeferredSignerSender is placed in the config bag.
After HTTP signing completes, the auth scheme retrieves it and sends the
concrete signer implementation through the channel.
Implementations
Sourceimpl DeferredSignerSender
impl DeferredSignerSender
Sourcepub fn new() -> (DeferredSignerReceiver, Self)
pub fn new() -> (DeferredSignerReceiver, Self)
Creates a new sender/receiver pair.